VideoViewPlayerController class
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
VideoViewValue> - VideoViewPlayerController
Constructors
- VideoViewPlayerController(String dataSource)
- VideoViewPlayerController.asset(String asset)
- VideoViewPlayerController.file(dynamic file)
- VideoViewPlayerController.networkUrl(Uri url)
Properties
- dataSource → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isDisposed → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textureId → int?
-
no setter
- value ↔ VideoViewValue
-
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → Future< void> -
Discards any resources used by the object.
override
-
initialize(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
pause(
) → Future< void> -
play(
) → Future< void> -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
seekTo(
Duration position) → Future< void> -
setDataSource(
String url) → Future< void> -
setLooping(
bool looping) → Future< void> -
setPlaybackSpeed(
double speed) → Future< void> -
setVolume(
double volume) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited