EatshotsVideoValue class

Annotations

Constructors

EatshotsVideoValue({Duration duration = Duration.zero, Duration position = Duration.zero, Size size = Size.zero, bool isInitialized = false, bool isPlaying = false, bool isBuffering = false, bool isLooping = true, String? errorDescription})
const

Properties

aspectRatio double
no setter
duration Duration
final
errorDescription String?
final
hasError bool
no setter
hashCode int
The hash code for this object.
no setterinherited
isBuffering bool
final
isInitialized bool
final
isLooping bool
final
isPlaying bool
final
position Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size
final

Methods

copyWith({Duration? duration, Duration? position, Size? size, bool? isInitialized, bool? isPlaying, bool? isBuffering, bool? isLooping, String? errorDescription}) EatshotsVideoValue
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited