VideoViewPlayerPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • VideoViewPlayerPlatform

Constructors

VideoViewPlayerPlatform()
Constructs a VideoViewPlayerPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
onNetworkTypeChanged Stream<String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelPrefetch(String url) Future<void>
dispose(int textureId) Future<void>
getNetworkType() Future<String>
getPlatformVersion() Future<String?>
getPosition(int textureId) Future<int>
initialize(String url) Future<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause(int textureId) Future<void>
play(int textureId) Future<void>
prefetch(String url, int bytes) Future<void>
seekTo(int textureId, Duration position) Future<void>
setDataSource(int textureId, String url) Future<void>
setLooping(int textureId, bool looping) Future<void>
setPlaybackSpeed(int textureId, double speed) Future<void>
setVolume(int textureId, double volume) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance VideoViewPlayerPlatform
The default instance of VideoViewPlayerPlatform to use.
getter/setter pair