MethodChannelVideoViewPlayer class
An implementation of VideoViewPlayerPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- VideoViewPlayerPlatform
- MethodChannelVideoViewPlayer
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
-
onNetworkTypeChanged
→ Stream<
String> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancelPrefetch(
String url) → Future< void> -
override
-
dispose(
int textureId) → Future< void> -
override
-
getNetworkType(
) → Future< String> -
override
-
getPlatformVersion(
) → Future< String?> -
override
-
getPosition(
int textureId) → Future< int> -
override
-
initialize(
String url) → Future< int> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pause(
int textureId) → Future< void> -
override
-
play(
int textureId) → Future< void> -
override
-
prefetch(
String url, int bytes) → Future< void> -
override
-
seekTo(
int textureId, Duration position) → Future< void> -
override
-
setDataSource(
int textureId, String url) → Future< void> -
override
-
setLooping(
int textureId, bool looping) → Future< void> -
override
-
setPlaybackSpeed(
int textureId, double speed) → Future< void> -
override
-
setVolume(
int textureId, double volume) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited